#[non_exhaustive]pub enum Error {
LaunchArgumentsNotSupported,
ParseValue(&'static str, ParseRawError),
ArgumentHasNulByte(&'static str),
ArgumentArrayElementHasNulByte(&'static str, usize),
Winapi(Error),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LaunchArgumentsNotSupported
Kernel drivers do not support launch arguments
ParseValue(&'static str, ParseRawError)
A parse error caused by an invalid raw value
ArgumentHasNulByte(&'static str)
An argument contains a nul byte
ArgumentArrayElementHasNulByte(&'static str, usize)
An argument array contains a nul byte in element at the given index
Winapi(Error)
IO error in winapi call