ServiceAccess

Struct ServiceAccess 

pub struct ServiceAccess(/* private fields */);
Flags describing the access permissions when working with services

Implementations

Source

impl ServiceAccess

pub const ALL_ACCESS: Self

Full access to the service object

pub const QUERY_STATUS: Self

Can query the service status

pub const START: Self

Can start the service

pub const STOP: Self

Can stop the service

pub const PAUSE_CONTINUE: Self

Can pause or continue the service execution

pub const INTERROGATE: Self

Can ask the service to report its status

pub const QUERY_CONFIG: Self

Can query the services configuration

pub const CHANGE_CONFIG: Self

Can change the services configuration

pub const USER_DEFINED_CONTROL: Self

Can use user-defined control codes

pub const DELETE: Self

Can delete the service

pub const READ_CONTROL: Self

Required to call the QueryServiceObjectSecurity function to query the security descriptor of the service object

pub const WRITE_DAC: Self

Required to call the SetServiceObjectSecurity function to modify the Dacl member of the service object’s security descriptor

pub const WRITE_OWNER: Self

Required to call the SetServiceObjectSecurity function to modify the Owner and Group members of the service object’s security descriptor

Source

impl ServiceAccess

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl ServiceAccess

pub const fn iter(&self) -> Iter<ServiceAccess>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ServiceAccess>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.