ServiceControlAccept

Struct ServiceControlAccept 

pub struct ServiceControlAccept(/* private fields */);
Flags describing accepted types of service control events.

Implementations

Source

impl ServiceControlAccept

pub const NETBIND_CHANGE: Self

The service is a network component that can accept changes in its binding without being stopped and restarted. This allows service to receive ServiceControl::Netbind* family of events.

pub const PARAM_CHANGE: Self

The service can reread its startup parameters without being stopped and restarted.

pub const PAUSE_CONTINUE: Self

The service can be paused and continued.

pub const PRESHUTDOWN: Self

The service can perform preshutdown tasks. Mutually exclusive with shutdown.

pub const SHUTDOWN: Self

The service is notified when system shutdown occurs. Mutually exclusive with preshutdown.

pub const STOP: Self

The service can be stopped.

pub const HARDWARE_PROFILE_CHANGE: Self

The service is notified when the computer’s hardware profile has changed. This enables the system to send SERVICE_CONTROL_HARDWAREPROFILECHANGE notifications to the service.

pub const POWER_EVENT: Self

The service is notified when the computer’s power status has changed. This enables the system to send SERVICE_CONTROL_POWEREVENT notifications to the service.

pub const SESSION_CHANGE: Self

The service is notified when the computer’s session status has changed. This enables the system to send SERVICE_CONTROL_SESSIONCHANGE notifications to the service.

pub const TIME_CHANGE: Self

The service is notified when the system time has changed. This enables the system to send SERVICE_CONTROL_TIMECHANGE notifications to the service.

pub const TRIGGER_EVENT: Self

The service is notified when an event for which the service has registered occurs. This enables the system to send SERVICE_CONTROL_TRIGGEREVENT notifications to the service.

Source

impl ServiceControlAccept

pub const fn empty() -> Self

Get a flags value with all bits unset.

Examples found in repository?
examples/ping_service.rs (line 139)
71    pub fn run_service() -> Result<()> {
72        // Create a channel to be able to poll a stop event from the service worker loop.
73        let (shutdown_tx, shutdown_rx) = mpsc::channel();
74
75        // Define system service event handler that will be receiving service events.
76        let event_handler = move |control_event| -> ServiceControlHandlerResult {
77            match control_event {
78                // Notifies a service to report its current status information to the service
79                // control manager. Always return NoError even if not implemented.
80                ServiceControl::Interrogate => ServiceControlHandlerResult::NoError,
81
82                // Handle stop
83                ServiceControl::Stop => {
84                    shutdown_tx.send(()).unwrap();
85                    ServiceControlHandlerResult::NoError
86                }
87
88                // treat the UserEvent as a stop request
89                ServiceControl::UserEvent(code) => {
90                    if code.to_raw() == 130 {
91                        shutdown_tx.send(()).unwrap();
92                    }
93                    ServiceControlHandlerResult::NoError
94                }
95
96                _ => ServiceControlHandlerResult::NotImplemented,
97            }
98        };
99
100        // Register system service event handler.
101        // The returned status handle should be used to report service status changes to the system.
102        let status_handle = service_control_handler::register(SERVICE_NAME, event_handler)?;
103
104        // Tell the system that service is running
105        status_handle.set_service_status(ServiceStatus {
106            service_type: SERVICE_TYPE,
107            current_state: ServiceState::Running,
108            controls_accepted: ServiceControlAccept::STOP,
109            exit_code: ServiceExitCode::Win32(0),
110            checkpoint: 0,
111            wait_hint: Duration::default(),
112            process_id: None,
113        })?;
114
115        // For demo purposes this service sends a UDP packet once a second.
116        let loopback_ip = IpAddr::from(LOOPBACK_ADDR);
117        let sender_addr = SocketAddr::new(loopback_ip, 0);
118        let receiver_addr = SocketAddr::new(loopback_ip, RECEIVER_PORT);
119        let msg = PING_MESSAGE.as_bytes();
120        let socket = UdpSocket::bind(sender_addr).unwrap();
121
122        loop {
123            let _ = socket.send_to(msg, receiver_addr);
124
125            // Poll shutdown event.
126            match shutdown_rx.recv_timeout(Duration::from_secs(1)) {
127                // Break the loop either upon stop or channel disconnect
128                Ok(_) | Err(mpsc::RecvTimeoutError::Disconnected) => break,
129
130                // Continue work if no events were received within the timeout
131                Err(mpsc::RecvTimeoutError::Timeout) => (),
132            };
133        }
134
135        // Tell the system that service has stopped.
136        status_handle.set_service_status(ServiceStatus {
137            service_type: SERVICE_TYPE,
138            current_state: ServiceState::Stopped,
139            controls_accepted: ServiceControlAccept::empty(),
140            exit_code: ServiceExitCode::Win32(0),
141            checkpoint: 0,
142            wait_hint: Duration::default(),
143            process_id: None,
144        })?;
145
146        Ok(())
147    }
pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl ServiceControlAccept

pub const fn iter(&self) -> Iter<ServiceControlAccept>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<ServiceControlAccept>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.