pub enum ServiceControlHandlerResult {
NoError,
NotImplemented,
Other(u32),
}Expand description
Abstraction over the return value of service control handler. The meaning of each of variants in this enum depends on the type of received event.
See the “Return value” section of corresponding MSDN article for more info:
https://msdn.microsoft.com/en-us/library/windows/desktop/ms683241(v=vs.85).aspx
Variants
NoError
Either used to acknowledge the call or grant the permission in advanced events.
NotImplemented
The received event is not implemented.
Other(u32)
This variant is used to deny permission and return the reason error code in advanced events.
Implementations