pub struct ServiceAccess(/* private fields */);Expand description
Flags describing the access permissions when working with services
Implementations
Sourceimpl ServiceAccess
impl ServiceAccess
Sourcepub const ALL_ACCESS: Self
pub const ALL_ACCESS: Self
Full access to the service object
Sourcepub const QUERY_STATUS: Self
pub const QUERY_STATUS: Self
Can query the service status
Sourcepub const PAUSE_CONTINUE: Self
pub const PAUSE_CONTINUE: Self
Can pause or continue the service execution
Sourcepub const INTERROGATE: Self
pub const INTERROGATE: Self
Can ask the service to report its status
Sourcepub const QUERY_CONFIG: Self
pub const QUERY_CONFIG: Self
Can query the services configuration
Sourcepub const CHANGE_CONFIG: Self
pub const CHANGE_CONFIG: Self
Can change the services configuration
Sourcepub const USER_DEFINED_CONTROL: Self
pub const USER_DEFINED_CONTROL: Self
Can use user-defined control codes
Sourcepub const READ_CONTROL: Self
pub const READ_CONTROL: Self
Required to call the QueryServiceObjectSecurity function to query the security descriptor of the service object
Sourcepub const WRITE_DAC: Self
pub const WRITE_DAC: Self
Required to call the SetServiceObjectSecurity function to modify the Dacl member of the service object’s security descriptor
Sourcepub const WRITE_OWNER: Self
pub const WRITE_OWNER: Self
Required to call the SetServiceObjectSecurity function to modify the Owner and Group members of the service object’s security descriptor
Sourceimpl ServiceAccess
impl ServiceAccess
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ServiceAccess
impl ServiceAccess
Sourcepub const fn iter(&self) -> Iter<ServiceAccess>
pub const fn iter(&self) -> Iter<ServiceAccess>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ServiceAccess>
pub const fn iter_names(&self) -> IterNames<ServiceAccess>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.